==> anwiba-spatial-data-gpsd-1.0.68-sources.jar: net/anwiba/spatial/gps/gpsd/response/Gst.java <==
//// Copyright (c) 2017 by Andreas W. Bartels (bartels@anwiba.de)
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonProperty;

public class Gst
    extends Response
{

    private final String _class = "GST";
    private String tag = null;
    private String device = null;
    private String time = null;
    private double rms = java.lang.Double.NaN;
    private double major = java.lang.Double.NaN;
    private double minor = java.lang.Double.NaN;
    private double orient = java.lang.Double.NaN;
    private double lat = java.lang.Double.NaN;
    private double lon = java.lang.Double.NaN;
    private double alt = java.lang.Double.NaN;

    @JsonProperty("class")
    public void setClass(final String _class) {
    }

    @JsonProperty("class")
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("tag")
    public void setTag(final String tag) {
        this.tag = tag;
    }

    @JsonProperty("tag")
    public String getTag() {
        return this.tag;
    }

    @JsonProperty("device")
    public void setDevice(final String device) {
        this.device = device;
    }

    @JsonProperty("device")
    public String getDevice() {
        return this.device;
    }

    @JsonProperty("time")
    public void setTime(final String time) {
        this.time = time;
    }

    @JsonProperty("time")
    public String getTime() {
        return this.time;
    }

    @JsonProperty("rms")
    public void setRms(final double rms) {
        this.rms = rms;
    }

    @JsonProperty("rms")
    public double getRms() {
        return this.rms;
    }

    @JsonProperty("major")
    public void setMajor(final double major) {
        this.major = major;
    }

    @JsonProperty("major")
    public double getMajor() {
        return this.major;
    }

    @JsonProperty("minor")
    public void setMinor(final double minor) {
        this.minor = minor;
    }

    @JsonProperty("minor")
    public double getMinor() {
        return this.minor;
    }

    @JsonProperty("orient")
    public void setOrient(final double orient) {
        this.orient = orient;
    }

    @JsonProperty("orient")
    public double getOrient() {
        return this.orient;
    }

    @JsonProperty("lat")
    public void setLat(final double lat) {
        this.lat = lat;
    }

    @JsonProperty("lat")
    public double getLat() {
        return this.lat;
    }

    @JsonProperty("lon")
    public void setLon(final double lon) {
        this.lon = lon;
    }

    @JsonProperty("lon")
    public double getLon() {
        return this.lon;
    }

    @JsonProperty("alt")
    public void setAlt(final double alt) {
        this.alt = alt;
    }

    @JsonProperty("alt")
    public double getAlt() {
        return this.alt;
    }

}

==> anwiba-spatial-data-gpsd-1.0.185-sources.jar: net/anwiba/spatial/gps/gpsd/response/Gst.java <==
//// Copyright (c) 2017 by Andreas W. Bartels
package net.anwiba.spatial.gps.gpsd.response;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;

public class Gst
    extends Response
{

    private final String _class = "GST";
    private String tag = null;
    private String device = null;
    private String time = null;
    private double rms = java.lang.Double.NaN;
    private double major = java.lang.Double.NaN;
    private double minor = java.lang.Double.NaN;
    private double orient = java.lang.Double.NaN;
    private double lat = java.lang.Double.NaN;
    private double lon = java.lang.Double.NaN;
    private double alt = java.lang.Double.NaN;

    @JsonIgnore
    public void setClass(final String _class) {
    }

    @JsonIgnore
    public String getCLASS() {
        return this._class;
    }

    @JsonProperty("tag")
    public void setTag(final String tag) {
        this.tag = tag;
    }

    @JsonProperty("tag")
    public String getTag() {
        return this.tag;
    }

    @JsonProperty("device")
    public void setDevice(final String device) {
        this.device = device;
    }

    @JsonProperty("device")
    public String getDevice() {
        return this.device;
    }

    @JsonProperty("time")
    public void setTime(final String time) {
        this.time = time;
    }

    @JsonProperty("time")
    public String getTime() {
        return this.time;
    }

    @JsonProperty("rms")
    public void setRms(final double rms) {
        this.rms = rms;
    }

    @JsonProperty("rms")
    public double getRms() {
        return this.rms;
    }

    @JsonProperty("major")
    public void setMajor(final double major) {
        this.major = major;
    }

    @JsonProperty("major")
    public double getMajor() {
        return this.major;
    }

    @JsonProperty("minor")
    public void setMinor(final double minor) {
        this.minor = minor;
    }

    @JsonProperty("minor")
    public double getMinor() {
        return this.minor;
    }

    @JsonProperty("orient")
    public void setOrient(final double orient) {
        this.orient = orient;
    }

    @JsonProperty("orient")
    public double getOrient() {
        return this.orient;
    }

    @JsonProperty("lat")
    public void setLat(final double lat) {
        this.lat = lat;
    }

    @JsonProperty("lat")
    public double getLat() {
        return this.lat;
    }

    @JsonProperty("lon")
    public void setLon(final double lon) {
        this.lon = lon;
    }

    @JsonProperty("lon")
    public double getLon() {
        return this.lon;
    }

    @JsonProperty("alt")
    public void setAlt(final double alt) {
        this.alt = alt;
    }

    @JsonProperty("alt")
    public double getAlt() {
        return this.alt;
    }

}
